:title: A Demo of \TeX{}Lite
:author: Lucien Rae Gentil
:fontsize: 11pt

# Introduction

TeXLite is a lightweight open-source tool for writing standard LaTeX/TeX documents in clean, Markdown-style syntax. With TeXLite, it's easy to write **good-looking documents with minimal overhead**.

# Demo

Here's some maths:

$$$
    e^{\pi i} + 1 = 0
$$$

TeXLive lets you use the **power** of \LaTeX{} with the *intuitive feel* of Markdown. It's still in development, so there are still plenty of features to come. If you have any issues or feature suggestions they are very, very welcome!


